Rearrange output from CalibrateSSB (calSSB object). Ready for input to PanelEstimation.
Source:R/CalibrateSSB.R
WideFromCalibrate.RdOne row for each id and one column for each wave.
Value
Output has the same elements (+ extra) as input (a), but rearranged. When subSet is input otput is alist according to the subSet levels.
Details
When wave, id or extra is NULL, corresponding elements in the input object (a) will be used if available,